.buttons {
    .clearfix();
}

.button {
    border: 0;
    background-color: transparent;
    background: @button-background;
    color: @button-color;
    width: 100%;
    text-align: center;
    float: left;
    line-height: @line-height-base;
    padding: 8px 4px;

    &:hover {
        color: @button-hover-color;
    }

    &:focus, &:hover {
        outline: none;
    }

    &.size-2 {
        width: 50%;
    }

    &.size-3 {
        width: 33%;
    }

    &.size-4 {
        width: 25%;
    }
}

